==> designate-2014.2.b3.tar.gz: designate-2014.2.b3/designate/mdns/middleware.py <==
# Copyright 2014 Hewlett-Packard Development Company, L.P.
#
# Author: Kiall Mac Innes <kiall@hp.com>
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.
from designate import context


class Middleware(object):
    def __init__(self, application):
        self.application = application

    def process_request(self, request):
        """Called on each request.

        If this returns None, the next application down the stack will be
        executed. If it returns a response then that response will be returned
        and execution will stop here.
        """
        return None

    def process_response(self, response):
        """Do whatever you'd like to the response."""
        return response

    def __call__(self, request):
        response = self.process_request(request)

        if response:
            return response

        response = self.application(request)
        return self.process_response(response)


class ContextMiddleware(Middleware):
    """Temporary ContextMiddleware which attaches an admin context to every
    request

    This will be replaced with a piece of middleware which generates, from
    a TSIG signed request, an approperiate Request Context.
    """
    def process_request(self, request):
        ctxt = context.DesignateContext.get_admin_context(all_tenants=True)
        request.environ['context'] = ctxt

        return None

==> designate-2015.1.0b1.tar.gz: designate-2015.1.0b1/designate/mdns/middleware.py <==
# Copyright 2014 Hewlett-Packard Development Company, L.P.
#
# Author: Kiall Mac Innes <kiall@hp.com>
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.
from designate import context


class Middleware(object):
    def __init__(self, application):
        self.application = application

    def process_request(self, request):
        """Called on each request.

        If this returns None, the next application down the stack will be
        executed. If it returns a response then that response will be returned
        and execution will stop here.
        """
        return None

    def process_response(self, response):
        """Do whatever you'd like to the response."""
        return response

    def __call__(self, request):
        response = self.process_request(request)

        if response:
            return response

        response = self.application(request)
        return self.process_response(response)


class ContextMiddleware(Middleware):
    """Temporary ContextMiddleware which attaches an admin context to every
    request

    This will be replaced with a piece of middleware which generates, from
    a TSIG signed request, an appropriate Request Context.
    """
    def process_request(self, request):
        ctxt = context.DesignateContext.get_admin_context(all_tenants=True)
        request.environ['context'] = ctxt

        return None
